@@ -2,7 +2,7 @@
 # Verify that ls works properly when it fails to stat a file that is
 # not mentioned on the command line.
 
-# Copyright (C) 2006-2013 Free Software Foundation, Inc.
+# Copyright (C) 2006-2023 Free Software Foundation, Inc.
 
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -15,21 +15,26 @@
 # GNU General Public License for more details.
 
 # You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
+# along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
 . "${srcdir=.}/tests/init.sh"; path_prepend_ ./src
 print_ver_ ls
 skip_if_root_
 
+LS_MINOR_PROBLEM=1
+
 mkdir d || framework_failure_
 ln -s / d/s || framework_failure_
 chmod 600 d || framework_failure_
 
 
-ls -Log d > out
-test $? = 1 || fail=1
+returns_ 1 ls -Log d > out || fail=1
 
-cat <<\EOF > exp || fail=1
+# Linux 2.6.32 client with Isilon OneFS always returns d_type==DT_DIR ('d')
+# Newer Linux 3.10.0 returns the more correct DT_UNKNOWN ('?')
+grep '^[l?]?' out || skip_ 'unrecognized d_type returned'
+
+cat <<\EOF > exp || framework_failure_
 total 0
 ?????????? ? ?            ? s
 EOF
@@ -38,9 +43,9 @@ sed 's/^l/?/' out | compare exp - || fail=1
 
 # Ensure that the offsets in --dired output are accurate.
 rm -f out exp
-ls --dired -l d > out && fail=1
+returns_ $LS_MINOR_PROBLEM ls --dired -l d > out || fail=1
 
-cat <<\EOF > exp || fail=1
+cat <<\EOF > exp || framework_failure_
   total 0
   ?????????? ? ? ? ?            ? s
 //DIRED// 44 45
